@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.09.15 22:00:00                  #
+# Updated Date: 2025.09.16 22:00:00                  #
 # ================================================== #
 
 from typing import Optional, List
@@ -479,7 +479,8 @@ class Ctx:
             id: int,
             restore_model: bool = True,
             select_idx: Optional[int] = None,
-            new_tab: Optional[bool] = False
+            new_tab: Optional[bool] = False,
+            no_fresh: bool = False
     ):
         """
         Load ctx data
@@ -488,6 +489,7 @@ class Ctx:
         :param restore_model: restore model if defined in ctx
         :param select_idx: select index on list after loading
         :param new_tab: open in new tab
+        :param no_fresh: do not fresh output
         """
         if new_tab:
             col_idx = self.window.controller.ui.tabs.column_idx
@@ -500,7 +502,7 @@ class Ctx:
         if meta is not None:
             self.set_group(meta.group_id)
 
-        if meta is not None:
+        if meta is not None and not no_fresh:
             self.fresh_output(meta)
 
         self.reload_config()
@@ -1287,14 +1289,19 @@ class Ctx:
 
     def reload(self):
         """Reload ctx"""
+        self.edit_meta_id = None
+        self.edit_item_id = None
+        self.group_id = None
+        self.selected = []
+        self._infinite_scroll_refresh = False
         self.reset_loaded_total()  # reset paging
         self.window.core.ctx.reset()
         self.setup()
-        self.update()
-        self.refresh()
 
     def reload_after(self):
         """After reload"""
+        self.update()
+        self.refresh()
         self.new_if_empty()
 
     def add_selected(self, id: int):
