@@ -6,9 +6,10 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.11.17 03:00:00                  #
+# Updated Date: 2025.09.19 00:00:00                  #
 # ================================================== #
 
+from .custom import Custom
 from .legacy import Legacy
 from .memory import Memory
 from .observer import Observer
@@ -24,6 +25,7 @@ class Agents:
         :param window: Window instance
         """
         self.window = window
+        self.custom = Custom(window)
         self.legacy = Legacy(window)
         self.memory = Memory(window)
         self.observer = Observer(window)
