@@ -1,3 +1,5 @@
+# core/agents/runners/llama_workflow.py
+
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 # ================================================== #
@@ -6,7 +8,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.24 02:00:00                  #
+# Updated Date: 2025.09.27 06:00:00                  #
 # ================================================== #
 
 import re
@@ -18,6 +20,7 @@ from llama_index.core.agent.workflow import (
     ToolCallResult,
     AgentStream,
     AgentOutput,
+    # AgentInput,  # not needed currently
 )
 from workflows.errors import WorkflowCancelledByUser
 
@@ -38,6 +41,7 @@ class LlamaWorkflow(BaseRunner):
         """
         super(LlamaWorkflow, self).__init__(window)
         self.window = window
+        self.last_response_id = None
 
     async def run(
             self,
@@ -48,6 +52,7 @@ class LlamaWorkflow(BaseRunner):
             verbose: bool = False,
             history: List[CtxItem] = None,
             llm: Any = None,
+            schema: Optional[List] = None,
     ) -> bool:
         """
         Run agent workflow
@@ -59,6 +64,7 @@ class LlamaWorkflow(BaseRunner):
         :param verbose: verbose mode
         :param history: chat history
         :param llm: LLM instance
+        :param schema: custom agent flow schema
         :return: True if success
         """
         if self.is_stopped():
@@ -175,12 +181,13 @@ class LlamaWorkflow(BaseRunner):
 
         prev_output = ctx.live_output
         if prev_output:
-            prev_output = self.filter_output(prev_output)  # remove all <execute>...</execute>
+            prev_output = self.filter_output(prev_output)  # remove all [!exec]...[/!exec]
 
         response_ctx.set_agent_final_response(ctx.agent_final_response)  # always set to further use
         response_ctx.set_output(prev_output)  # append from stream
         response_ctx.extra["agent_output"] = True  # mark as output response
         response_ctx.extra["agent_finish"] = True  # mark as finished
+        response_ctx.set_agent_name(ctx.get_agent_name()) # store last agent name
 
         if "agent_input" in response_ctx.extra:
             del response_ctx.extra["agent_input"]  # remove agent input from extra
@@ -252,6 +259,14 @@ class LlamaWorkflow(BaseRunner):
         item_ctx.output = ""  # empty to prevent render
         item_ctx.stream = ""  # for stream
 
+        # Keep last known agent name to avoid redundant ctx updates.
+        last_agent_name: Optional[str] = None
+
+        # Track whether current block has already produced user-visible tokens.
+        # This prevents creating empty DB items and preserves order.
+        content_written: bool = False
+        block_open: bool = False  # logical "block" opened after first StepEvent
+
         async for event in handler.stream_events():
             if self.is_stopped():
                 # persist current output on stop
@@ -261,6 +276,7 @@ class LlamaWorkflow(BaseRunner):
                     self.end_stream(item_ctx, signals)
                 await handler.cancel_run()  # cancel, will raise WorkflowCancelledByUser
                 break
+
             if isinstance(event, ToolCallResult):
                 output = f"\n-----------\nExecution result:\n{event.tool_output}"
                 if verbose:
@@ -268,8 +284,11 @@ class LlamaWorkflow(BaseRunner):
                 formatted = "\n```output\n" + str(event.tool_output) + "\n```\n"
                 item_ctx.live_output += formatted
                 item_ctx.stream = formatted
+                content_written = True
                 if item_ctx.stream_agent_output and flush:
                     self.send_stream(item_ctx, signals, begin)
+                begin = False
+
             elif isinstance(event, ToolCall):
                 if "code" in event.tool_kwargs:
                     output = f"\n-----------\nTool call code:\n{event.tool_kwargs['code']}"
@@ -278,37 +297,97 @@ class LlamaWorkflow(BaseRunner):
                     formatted = "\n```python\n" + str(event.tool_kwargs['code']) + "\n```\n"
                     item_ctx.live_output += formatted
                     item_ctx.stream = formatted
+                    content_written = True
                     if item_ctx.stream_agent_output and flush:
                         self.send_stream(item_ctx, signals, begin)
+                    begin = False
+
             elif isinstance(event, StepEvent):
+                # UI splitting strategy aligned with OpenAI flow:
+                # - do NOT start a new DB item at the first StepEvent
+                # - only finalize the previous item if it already produced content
+                #   (prevents empty items and ordering glitches)
                 self.set_busy(signals)
                 if not use_partials:
+                    # We still want to propagate the name early if provided.
+                    try:
+                        meta = getattr(event, "meta", {}) or {}
+                        next_name = meta.get("agent_name")
+                        if next_name:
+                            last_agent_name = self._apply_agent_name_to_ctx(item_ctx, next_name, last_agent_name)
+                    except Exception:
+                        pass
+                    begin = True
                     continue
+
                 if verbose:
                     print("\n\n-----STEP-----\n\n")
                     print(f"[{event.name}] {event.index}/{event.total} meta={event.meta}")
-                if flush:
-                    item_ctx = self.on_next_ctx(
-                        item_ctx,
-                        signals=signals,
-                        begin=begin,
-                        stream=True,
-                    )
+
+                # If there was an open block with content -> finalize it to a new DB item.
+                if block_open and content_written:
+                    if flush:
+                        item_ctx = self.on_next_ctx(
+                            item_ctx,
+                            signals=signals,
+                            begin=begin,
+                            stream=True,
+                        )
+                    # Apply next agent name on the fresh ctx (so UI header is correct from token #1).
+                    try:
+                        meta = getattr(event, "meta", {}) or {}
+                        next_name = meta.get("agent_name")
+                        if next_name:
+                            last_agent_name = self._apply_agent_name_to_ctx(item_ctx, next_name, last_agent_name)
+                    except Exception:
+                        pass
+                else:
+                    # First step or previous step had no visible content: just propagate the name.
+                    try:
+                        meta = getattr(event, "meta", {}) or {}
+                        next_name = meta.get("agent_name")
+                        if next_name:
+                            last_agent_name = self._apply_agent_name_to_ctx(item_ctx, next_name, last_agent_name)
+                    except Exception:
+                        pass
+
+                # Prepare for the upcoming tokens (new block begins).
+                block_open = True
+                content_written = False
+                begin = True
+                continue
+
             elif isinstance(event, AgentStream):
+                # Update agent name from event if present; fallback to header parsing.
+                name = getattr(event, "current_agent_name", None)
+                if not name:
+                    name = self._guess_agent_name_from_text(getattr(event, "delta", "") or "")
+                if name:
+                    last_agent_name = self._apply_agent_name_to_ctx(item_ctx, name, last_agent_name)
+
                 if verbose:
                     print(f"{event.delta}", end="", flush=True)
                 if event.delta:
                     item_ctx.live_output += event.delta
                     item_ctx.stream = event.delta
+                    content_written = True
                     if item_ctx.stream_agent_output and flush:
                         self.send_stream(item_ctx, signals, begin)  # send stream to webview
                     begin = False
+
             elif isinstance(event, AgentOutput):
+                # Ensure final agent name is applied as well.
+                name = getattr(event, "current_agent_name", None)
+                if name:
+                    last_agent_name = self._apply_agent_name_to_ctx(item_ctx, name, last_agent_name)
                 thought, answer = self.extract_final_response(str(event))
                 if answer:
                     item_ctx.set_agent_final_response(answer)
                     if verbose:
                         print(f"\nFinal response: {answer}")
+                # Do not split the block here – we will either:
+                # - split on the next StepEvent, or
+                # - finalize once at the end (make_response), just like OpenAI flow does.
 
         return item_ctx
 
@@ -345,6 +424,40 @@ class LlamaWorkflow(BaseRunner):
         next_ctx.set_output("")
         next_ctx.partial = True
         next_ctx.extra["agent_output"] = True  # allow usage in history
-
+        next_ctx.set_agent_name(ctx.get_agent_name())  # propagate agent name
         self.send_response(next_ctx, signals, KernelEvent.APPEND_DATA)
-        return next_ctx
\ No newline at end of file
+
+        return next_ctx
+
+    # ===== helpers for agent name propagation =====
+
+    def _apply_agent_name_to_ctx(self, ctx: CtxItem, name: str, last_known: Optional[str]) -> str:
+        """
+        Apply agent name to your context, avoiding redundant updates.
+        Falls back to ctx.extra['agent_name'] if set_agent_name is unavailable.
+        """
+        if not name:
+            return last_known or ""
+        if last_known and last_known == name:
+            return last_known
+        try:
+            if hasattr(ctx, "set_agent_name") and callable(getattr(ctx, "set_agent_name")):
+                ctx.set_agent_name(name)
+            # Always mirror into extra for downstream consumers
+            ctx.extra["agent_name"] = name
+        except Exception:
+            ctx.extra["agent_name"] = name
+        return name
+
+    def _guess_agent_name_from_text(self, text: str) -> Optional[str]:
+        """
+        Try to infer agent name from header like '**Name**' which our workflow emits
+        before each agent block.
+        """
+        if not text:
+            return None
+        # Look for the first bold segment – keep it lenient
+        m = re.search(r"\*\*([^*]+?)\*\*", text)
+        if m:
+            return m.group(1).strip()
+        return None
\ No newline at end of file
