@@ -6,16 +6,21 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.01 19:00:00                  #
+# Updated Date: 2025.09.04 00:00:00                  #
 # ================================================== #
 
-from typing import Optional
+from dataclasses import dataclass
+from typing import Optional, ClassVar
 
 from .base import BaseEvent
+from ...item.ctx import CtxItem
 
 
+@dataclass(slots=True)
 class KernelEvent(BaseEvent):
     """Kernel events"""
+    # static id for event family
+    id: ClassVar[str] = "KernelEvent"
 
     # core, events sent from kernel
     INIT = "kernel.init"
@@ -50,23 +55,9 @@ class KernelEvent(BaseEvent):
     # state
     STATE = "kernel.state"
     STATE_BUSY = "kernel.state.busy"
-    STATE_IDLE = "kernel.state.idle"
     STATE_ERROR = "kernel.state.error"
+    STATE_IDLE = "kernel.state.idle"
     STATUS = "kernel.status"
 
     LIVE_APPEND = "kernel.live.append"
-    LIVE_CLEAR = "kernel.live.clear"
-
-    def __init__(
-            self,
-            name: Optional[str] = None,
-            data: Optional[dict] = None,
-    ):
-        """
-        Event object class
-
-        :param name: event name
-        :param data: event data
-        """
-        super(KernelEvent, self).__init__(name, data)
-        self.id = "KernelEvent"
+    LIVE_CLEAR = "kernel.live.clear"
\ No newline at end of file
