@@ -6,20 +6,23 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.30 00:00:00                  #
+# Updated Date: 2025.08.28 09:00:00                  #
 # ================================================== #
 
-MODE_AUDIO = "audio"
-MODE_CHAT = "chat"
-MODE_COMPLETION = "completion"
-MODE_IMAGE = "img"
-MODE_VISION = "vision"
-MODE_ASSISTANT = "assistant"
-MODE_LANGCHAIN = "langchain"
-MODE_LLAMA_INDEX = "llama_index"
 MODE_AGENT = "agent"
 MODE_AGENT_LLAMA = "agent_llama"
 MODE_AGENT_OPENAI = "agent_openai"
+MODE_ASSISTANT = "assistant"
+MODE_AUDIO = "audio"
+MODE_CHAT = "chat"
+MODE_COMPLETION = "completion"
+MODE_COMPUTER = "computer"
 MODE_EXPERT = "expert"
+MODE_IMAGE = "img"
+MODE_LANGCHAIN = "langchain"
+MODE_LLAMA_INDEX = "llama_index"
 MODE_RESEARCH = "research"
-MODE_COMPUTER = "computer"
\ No newline at end of file
+MODE_VISION = "vision"
+
+# virtual modes
+MODE_LOOP_NEXT = "loop_next"
\ No newline at end of file
