@@ -15,7 +15,7 @@ from pydantic import BaseModel
 from agents import Agent
 
 from pygpt_net.item.preset import PresetItem
-from pygpt_net.provider.gpt.agents.remote_tools import append_tools
+from pygpt_net.provider.api.openai.agents.remote_tools import append_tools
 
 
 class ReportData(BaseModel):
@@ -37,7 +37,7 @@ def get_writer_agent(
     kwargs = {
         "name": "WriterAgent",
         "instructions": config["prompt"],
-        "model": config["model"].id,
+        "model": window.core.agents.provider.get_openai_model(config["model"]),
         "output_type": ReportData,
     }
     if config.get("experts"):
