@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.09.22 19:00:00                  #
+# Updated Date: 2025.09.26 03:00:00                  #
 # ================================================== #
 
 import copy
@@ -151,6 +151,23 @@ class Patch:
                     data["ctx.urls.internal"] = False
                 updated = True
 
+            # < 2.6.61
+            if old < parse_version("2.6.61"):
+                print("Migrating config from < 2.6.61...")
+                if "presets.drag_and_drop.enabled" not in data:
+                    data["presets.drag_and_drop.enabled"] = True
+                if "presets_order" not in data:
+                    data["presets_order"] = {}
+                updated = True
+
+            # < 2.6.62
+            if old < parse_version("2.6.62"):
+                print("Migrating config from < 2.6.62...")
+                # add: node editor css
+                patch_css('style.light.css', True)
+                patch_css('style.dark.css', True)
+                updated = True
+
         # update file
         migrated = False
         if updated:
