@@ -1,3 +1,4 @@
+# ui/layout/presets.py
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 # ================================================== #
@@ -6,11 +7,11 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.09.05 18:00:00                  #
+# Updated Date: 2025.09.26 13:30:00                  #
 # ================================================== #
 
 from PySide6 import QtCore
-from PySide6.QtGui import QStandardItemModel, Qt, QIcon
+from PySide6.QtGui import QStandardItemModel, QStandardItem, Qt, QIcon
 from PySide6.QtWidgets import QVBoxLayout, QHBoxLayout, QPushButton, QWidget, QSizePolicy
 
 from pygpt_net.core.types import (
@@ -113,35 +114,52 @@ class Presets:
         nodes = self.window.ui.nodes
         models = self.window.ui.models
 
-        view = nodes[self.id]
+        view: PresetList = nodes[self.id]
         model = models.get(self.id)
 
-        view.backup_selection()
+        # If view requested selection override, do NOT override it by backup
+        selection_override_ids = getattr(view, "_selection_override_ids", None)
+        if not selection_override_ids:
+            view.backup_selection()
 
         if model is None:
             model = self.create_model(self.window)
             models[self.id] = model
             view.setModel(model)
 
+        # Preserve current scroll position across model rebuild to avoid a visible jump to the top.
+        # This is applied while updates are disabled, then restored just before re-enabling them.
+        try:
+            v = view.verticalScrollBar().value()
+            h = view.horizontalScrollBar().value()
+            view.set_pending_v_scroll(v)
+            view.set_pending_h_scroll(h)
+        except Exception:
+            pass
+
+        # Block user input during model rebuild to avoid crashes on quick clicks
+        view.begin_model_update()
+
+        # Turn off updates to avoid flicker and transient artifacts
         view.setUpdatesEnabled(False)
         try:
-            if not data:
-                model.setRowCount(0)
-            else:
-                count = len(data)
-                model.setRowCount(count)
+            # Rebuild model cleanly to avoid any stale items causing visual glitches
+            model.clear()
+            model.setColumnCount(1)
 
+            if data:
                 is_expert_mode = (mode == MODE_EXPERT)
                 is_agent_mode = (mode == MODE_AGENT)
                 count_experts = self.window.core.experts.count_experts if is_agent_mode else None
                 startswith_current = "current."
 
-                index_fn = model.index
-                set_item_data = model.setItemData
-                display_role = QtCore.Qt.DisplayRole
-                tooltip_role = QtCore.Qt.ToolTipRole
+                role_uuid = QtCore.Qt.UserRole + 1
+                role_id = QtCore.Qt.UserRole + 2
+                role_is_special = QtCore.Qt.UserRole + 3
 
                 for i, (key, item) in enumerate(data.items()):
+                    qitem = QStandardItem()
+
                     name = item.name
                     if is_expert_mode and item.enabled and not key.startswith(startswith_current):
                         name = f"[x] {name}"
@@ -153,9 +171,39 @@ class Presets:
                     prompt = str(item.prompt)
                     tooltip = prompt if len(prompt) <= 80 else f"{prompt[:80]}..."
 
-                    idx = index_fn(i, 0)
-                    set_item_data(idx, {display_role: name, tooltip_role: tooltip})
+                    qitem.setText(name)
+                    qitem.setToolTip(tooltip)
+                    qitem.setData(item.uuid, role_uuid)
+                    qitem.setData(key, role_id)
+                    qitem.setData(key.startswith(startswith_current), role_is_special)
+
+                    # Pin row 0 (no drag, no drop)
+                    # Other rows: drag enabled only; drop is handled by view between rows
+                    if i != 0 and not key.startswith(startswith_current):
+                        flags = Qt.ItemIsEnabled | Qt.ItemIsSelectable | Qt.ItemIsDragEnabled
+                    else:
+                        flags = Qt.ItemIsEnabled | Qt.ItemIsSelectable
+                    qitem.setFlags(flags)
+
+                    model.appendRow(qitem)
         finally:
+            # Apply pending scroll (if any) before re-enabling updates
+            view.apply_pending_scroll()
             view.setUpdatesEnabled(True)
 
-        view.restore_selection()
\ No newline at end of file
+        dnd_enabled = bool(self.window.core.config.get('presets.drag_and_drop.enabled'))
+        view.set_dnd_enabled(dnd_enabled)
+
+        # If override requested, force saved selection IDs to those override IDs
+        if selection_override_ids:
+            view._saved_selection_ids = list(selection_override_ids)
+            view._selection_override_ids = None  # consume one-shot override
+
+        # Restore selection by ID (so it follows the same item even if rows moved)
+        view.restore_selection()
+        # Force repaint in case Qt defers layout until next input
+        view.viewport().update()
+
+        # Clear one-shot pending scroll values and re-enable user interaction
+        view.clear_pending_scroll()
+        view.end_model_update()
\ No newline at end of file
