@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.09.14 20:00:00                  #
+# Updated Date: 2025.09.16 22:00:00                  #
 # ================================================== #
 
 from typing import Any
@@ -35,6 +35,35 @@ class TabBody(QTabWidget):
             self.on_delete(self)
         self.delete_refs()
 
+    def unwrap(self, widget: QWidget) -> None:
+        """
+        Remove widget from tab body
+
+        :param widget: widget to remove
+        """
+        layout = self.layout()
+        if layout is not None:
+            layout.removeWidget(widget)
+        self.delete_ref(widget)
+
+    def unwrap_all(self) -> None:
+        """
+        Remove all widgets from tab body
+        """
+        layout = self.layout()
+        if layout is not None:
+            while layout.count():
+                item = layout.takeAt(0)
+                widget = item.widget()
+                try:
+                    layout.removeWidget(widget)
+                except Exception:
+                    pass
+                try:
+                    self.delete_ref(widget)
+                except Exception:
+                    pass
+
     def add_ref(self, ref: Any) -> None:
         """
         Add reference to widget in this tab
@@ -135,4 +164,16 @@ class TabBody(QTabWidget):
             if self.owner is not None:
                 col_idx = self.owner.column_idx
                 self.window.controller.ui.tabs.on_column_focus(col_idx)
-        return super().eventFilter(source, event)
\ No newline at end of file
+        return super().eventFilter(source, event)
+
+    def to_dict(self) -> dict:
+        """
+        Convert to dict
+
+        :return: dict
+        """
+        return {
+            "refs": [str(ref) for ref in self.refs],  # references to widgets
+            "body": [str(b) for b in self.body],  # body widgets
+            "len(layout)": self.layout().count() if self.layout() else 0,
+        }
\ No newline at end of file
