@@ -6,15 +6,15 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.09.11 08:00:00                  #
+# Updated Date: 2025.09.16 02:00:00                  #
 # ================================================== #
-
+from PySide6 import QtCore
 from PySide6.QtCore import Qt, QObject, Signal, Slot, QEvent, QUrl, QCoreApplication, QEventLoop
 from PySide6.QtWebChannel import QWebChannel
 from PySide6.QtWebEngineCore import QWebEngineSettings, QWebEnginePage, QWebEngineProfile
 from PySide6.QtWebEngineWidgets import QWebEngineView
 from PySide6.QtGui import QAction, QIcon
-from PySide6.QtWidgets import QMenu
+from PySide6.QtWidgets import QMenu, QDialog, QVBoxLayout
 
 from pygpt_net.core.events import RenderEvent
 from pygpt_net.item.ctx import CtxMeta
@@ -22,6 +22,7 @@ from pygpt_net.core.text.web_finder import WebFinder
 from pygpt_net.ui.widget.tabs.layout import FocusEventFilter
 from pygpt_net.utils import trans
 
+
 class ChatWebOutput(QWebEngineView):
     def __init__(self, window=None):
         """
@@ -43,117 +44,185 @@ class ChatWebOutput(QWebEngineView):
         self.meta = None
         self.tab = None
         self.setProperty('class', 'layout-output-web')
+        self.setMouseTracking(True)
 
         # OpenGL widgets
         self._glwidget = None
         self._glwidget_filter_installed = False
+        self._unloaded = False
+        self._destroyed = False
 
         # set the page with a shared profile
         self.setUpdatesEnabled(False)  # disable updates until the page is set, re-enable in `on_page_loaded`
 
-        self._profile = QWebEngineProfile(self)
+        # self._profile = self._make_profile(self)
+        self.setPage(CustomWebEnginePage(self.window, self, profile=None))
+
+    def _make_profile(self, parent=None) -> QWebEngineProfile:
+        """Make profile"""
+        profile = QWebEngineProfile(parent)
         # self._profile.setHttpCacheType(QWebEngineProfile.MemoryHttpCache)
         # self._profile.setHttpCacheMaximumSize(32 * 1024 * 1024)  # 32MB
-        self._profile.setPersistentCookiesPolicy(QWebEngineProfile.NoPersistentCookies)
+        profile.setPersistentCookiesPolicy(QWebEngineProfile.NoPersistentCookies)
         # self._profile.setHttpCacheType(QWebEngineProfile.NoCache)
-        self._profile.setSpellCheckEnabled(False)
-        # self._profile.setOffTheRecord(True)
-        self.setPage(CustomWebEnginePage(self.window, self, profile=self._profile))
+        profile.setSpellCheckEnabled(False)
+        return profile
+
 
     def _detach_gl_event_filter(self):
         """Detach OpenGL widget event filter if installed"""
         if self._glwidget and self._glwidget_filter_installed:
             try:
                 self._glwidget.removeEventFilter(self)
-            except Exception:
-                pass
+            except Exception as e:
+                self._on_delete_failed(e)
         self._glwidget = None
         self._glwidget_filter_installed = False
 
+    def _on_delete_failed(self, e):
+        """
+        Handle delete failure
+
+        :param e: Exception instance
+        """
+        pass
+        # self.window.core.debug.log(e)
+
+    def show_devtools(self, modal: bool = False, title: str = "DevTools"):
+        """Show DevTools window"""
+        if getattr(self, "_devtools_dlg", None) is None:
+            dlg = QDialog(self.window)
+            dlg.setWindowTitle(title)
+            dlg.setModal(modal)
+            dlg.setAttribute(Qt.WA_DeleteOnClose, True)
+            dlg.resize(1100, 750)
+
+            layout = QVBoxLayout(dlg)
+            view = QWebEngineView(dlg)
+            layout.addWidget(view)
+
+            profile = self.page().profile()
+            view.setPage(QWebEnginePage(profile, view))
+
+            self.page().setDevToolsPage(view.page())
+
+            dlg.destroyed.connect(lambda: setattr(self, "_devtools_dlg", None))
+
+            self._devtools_dlg = dlg
+            self._devtools_view = view
+
+        self._devtools_dlg.show()
+        self._devtools_dlg.raise_()
+        self._devtools_dlg.activateWindow()
+
+    def unload(self):
+        """Unload the current page and free resources"""
+        try:
+            self.hide()
+            p = self.page()
+            p.triggerAction(QWebEnginePage.Stop)
+            p.setUrl(QUrl("about:blank"))
+            p.history().clear()
+            p.setLifecycleState(QWebEnginePage.LifecycleState.Discarded)
+        except Exception as e:
+            self._on_delete_failed(e)
+        finally:
+            self._unloaded = True
+
     def on_delete(self):
         """Clean up on delete"""
+        if self._destroyed:
+            return
+        if not self._unloaded:
+            self.unload()
+
         self.hide()
         self._detach_gl_event_filter()
-        
+
         if self.finder:
             try:
                 self.finder.disconnect()
-            except Exception:
-                pass
-            self.finder = None
+            except Exception as e:
+                self._on_delete_failed(e)
+            finally:
+                self.finder = None
 
         self.tab = None
         self.meta = None
 
         # safely unhook signals (may not have been hooked)
         for sig, slot in (
-            (self.loadFinished, self.on_page_loaded),
-            (self.customContextMenuRequested, self.on_context_menu),
-            (self.signals.save_as, getattr(self.window.controller.chat.render, "handle_save_as", None)),
-            (self.signals.audio_read, getattr(self.window.controller.chat.render, "handle_audio_read", None)),
+                (self.loadFinished, self.on_page_loaded),
+                (self.customContextMenuRequested, self.on_context_menu),
+                (self.signals.save_as, getattr(self.window.controller.chat.render, "handle_save_as", None)),
+                (self.signals.audio_read, getattr(self.window.controller.chat.render, "handle_audio_read", None)),
         ):
             if slot:
                 try:
                     sig.disconnect(slot)
-                except Exception:
-                    pass
+                except Exception as e:
+                    self._on_delete_failed(e)
 
         page = self.page()
         page.set_loaded(False)
 
         try:
             page.triggerAction(QWebEnginePage.Stop)
-        except Exception:
-            pass
+        except Exception as e:
+            self._on_delete_failed(e)
+
         try:
             page.setUrl(QUrl("about:blank"))
-        except Exception:
-            pass
+        except Exception as e:
+            self._on_delete_failed(e)
+
         try:
             page.history().clear()
-        except Exception:
-            pass
+        except Exception as e:
+            self._on_delete_failed(e)
+
         try:
             page.setLifecycleState(QWebEnginePage.LifecycleState.Discarded)
-        except Exception:
-            pass
+        except Exception as e:
+            self._on_delete_failed(e)
+
         try:
             if hasattr(page, "setWebChannel"):
                 page.setWebChannel(None)
-        except Exception:
-            pass
-        try:
-            self.disconnect()
-        except Exception:
-            pass
+        except Exception as e:
+            self._on_delete_failed(e)
 
         prof = None
         try:
             prof = page.profile()
-        except Exception:
-            pass
+        except Exception as e:
+            self._on_delete_failed(e)
 
         try:
             page.cleanup()
-        except Exception:
-            pass
+        except Exception as e:
+            self._on_delete_failed(e)
 
+        """
         if prof is not None:
             try:
                 prof.deleteLater()
-            except Exception:
-                pass
+            except Exception as e:
+                self._on_delete_failed(e)
+        """
 
         try:
             self.deleteLater()
-        except Exception:
-            pass
+        except Exception as e:
+            self._on_delete_failed(e)
 
         try:
             QCoreApplication.sendPostedEvents(None, QEvent.DeferredDelete)
             QCoreApplication.processEvents(QEventLoop.AllEvents, 50)
-        except Exception:
-            pass
+        except Exception as e:
+            self._on_delete_failed(e)
+
+        self._destroyed = True
 
     def eventFilter(self, source, event):
         """
@@ -390,6 +459,7 @@ class ChatWebOutput(QWebEngineView):
 
 class CustomWebEnginePage(QWebEnginePage):
     """Custom WebEnginePage to handle web events"""
+
     def __init__(self, window, view, profile: QWebEngineProfile = None):
 
         # use the profile if provided, otherwise the default
@@ -461,7 +531,7 @@ class CustomWebEnginePage(QWebEnginePage):
         return super().acceptNavigationRequest(url, _type, isMainFrame)
 
     def javaScriptConsoleMessage(self, level, message, line_number, source_id):
-        # print("[JS CONSOLE] Line", line_number, ":", message)
+        #  print("[JS CONSOLE] Line", line_number, ":", message)
         self.signals.js_message.emit(line_number, message, source_id)  # handled in debug controller
 
     def cleanup(self):
@@ -495,12 +565,10 @@ class CustomWebEnginePage(QWebEnginePage):
                 pass
             self.signals = None
 
-        # delete the page object
-        self.deleteLater()
-
 
 class Bridge(QObject):
     """Bridge between Python and JavaScript"""
+
     def __init__(self, window, parent=None):
         super(Bridge, self).__init__(parent)
         self.window = window
